
## Please use the following structure as "header" entries for python files:
## everything inside the -------- code block--------
## should be present. 
### __data__ is used for creation date__
### __version__ we follow a major.minor.micro structure. The first release was unified to version 0.1.0


----------- beginning of file, no empty lines ------------
#!/usr/bin/env python
# -*- coding: utf-8 -*-

"""
    Informative description abouth module
"""

__author__      = ["Claudio D'Onofrio"]
__credits__     = "ICOS Carbon Portal"
__license__     = "GPL-3.0"
__version__     = "0.1.0"
__maintainer__  = "ICOS Carbon Portal, elaborated products team"
__email__       = ['info@icos-cp.eu', 'claudio.donofrio@nateko.lu.se']
__status__      = "rc1"
__date__        = "2019-08-09"


------------ end of header entries -----------------------